@@ -1,8 +1,8 @@
 /********************************************************************
- * $Author: lindner $
- * $Revision: 3.24 $
- * $Date: 1996/01/04 18:28:52 $
- * $Source: /home/arcwelder/GopherSrc/CVS/gopher+/gopher/CURcurses.h,v $
+ * $Author: jgoerzen $
+ * $Revision: 1.6 $
+ * $Date: 2002/04/26 13:33:33 $
+ * $Source: /var/cvs/gopher/gopher/CURcurses.h,v $
  * $State: Exp $
  *
  * Paul Lindner, University of Minnesota CIS.
@@ -15,6 +15,24 @@
  *********************************************************************
  * Revision History:
  * $Log: CURcurses.h,v $
+ * Revision 1.6  2002/04/26 13:33:33  jgoerzen
+ * Removed glib MIME stuff.  We'll move to Pygopherd first.
+ *
+ * Revision 1.4.2.1  2002/03/21 15:24:56  jgoerzen
+ * Fixes for Solaris.  Also commited on main branch.
+ *
+ * Revision 1.4  2001/01/17 21:48:05  jgoerzen
+ * Many fixes and tune-ups.  Now compiles cleanly with -Wall -Werror!
+ *
+ * Revision 1.3  2001/01/03 22:26:27  s2mdalle
+ * Code cleanups, addition of a few prototypes from CURcurses.c
+ *
+ * Revision 1.2  2000/12/27 21:24:04  s2mdalle
+ * Added many function prototypes from CURcurses.c
+ *
+ * Revision 1.1.1.1  2000/08/19 00:28:56  jgoerzen
+ * Import from UMN Gopher 2.3.1 after GPLization
+ *
  * Revision 3.24  1996/01/04  18:28:52  lindner
  * Updates for autoconf
  *
@@ -245,12 +263,12 @@ typedef struct Requestitem_struct Requestitem;
 #define CURsetSIGTSTP(a,b) ((a)->sigtstp=(b))
 #define CURsetSIGWINCH(a,b) ((a)->sigwinch=(b))
 
-#if defined(SYSVCURSES) || defined(A_BOLD)
-#define wboldout(win)       (wattron(win, A_BOLD))
-#define wboldend(win)       (wattroff(win, A_BOLD))
-#else
+#ifdef HAVE_WSTANDOUT
 #define wboldout(win)       (wstandout(win))
 #define wboldend(win)       (wstandend(win))
+#else
+#define wboldout(win)       (wattron(win, A_BOLD))
+#define wboldend(win)       (wattroff(win, A_BOLD))
 #endif
 
 #define CURgetBox_ul(a)  ((a)->Box_ul)
@@ -276,11 +294,25 @@ void      CURexit(CursesObj *cur);
 int       CURgetstr();
 int       CURgetch(CursesObj *cur);
 void      CURresize(CursesObj *cur);
-int       CURoutchar(char c);
+int       CURoutchar(int c);
 int       CURGetOneOption(CursesObj *cur, char *Title, char *OptionName,
 			  char *Response);
 void      CURBeep(CursesObj *cur);
 void      CURwenter(CursesObj *cur, WINDOW *win);
 void      CURsetGraphicsChars(CursesObj *cur, char *termtype);
+int       CUROldGetOneOption(CursesObj *cur, char *OptionName, char *Response);
+int       CURwgetch(CursesObj *cur, WINDOW *window);
+int       CURrequester(CursesObj *cur, char *Wintitle, Requestitem **items);
+int       CURDialog(CursesObj *cur, char *Wintitle, char **Message);
+void      CURgetYesorNo(CursesObj *cur, char *OptionName, char *Response);
+int       CURRequest(CursesObj *cur, char *Wintitle, char **Prompts, 
+                     char **Stowages);
 
+int       CURChoice(CursesObj *cur, char *WinTitle, char **Choices, 
+                    char *Prompt, int DefaultChoice);
+void      CURbutton(CursesObj *cur, WINDOW *win, char *Label, boolean bright);
+void      CURbox(CursesObj *cur, WINDOW *win, int height, int width);
+int       CURwgetstr(CursesObj *cur, WINDOW *win, char *inputline, 
+                     int maxlength, boolean hidden);
 #endif  /* CURCURSES_H */
+
