@@ -1,8 +1,8 @@
 /********************************************************************
- * $Author: lindner $
- * $Revision: 3.5 $
- * $Date: 1995/09/26 05:16:30 $
- * $Source: /home/arcwelder/GopherSrc/CVS/gopher+/object/BLblock.h,v $
+ * $Author: jgoerzen $
+ * $Revision: 1.2 $
+ * $Date: 2000/12/20 01:19:20 $
+ * $Source: /var/cvs/gopher/object/BLblock.h,v $
  * $State: Exp $
  *
  * Paul Lindner, University of Minnesota CIS.
@@ -15,6 +15,12 @@
  *********************************************************************
  * Revision History:
  * $Log: BLblock.h,v $
+ * Revision 1.2  2000/12/20 01:19:20  jgoerzen
+ * Added patches from David Allen <s2mdalle@titan.vcu.edu>
+ *
+ * Revision 1.1.1.1  2000/08/19 00:28:56  jgoerzen
+ * Import from UMN Gopher 2.3.1 after GPLization
+ *
  * Revision 3.5  1995/09/26  05:16:30  lindner
  * more fixes...
  *
@@ -43,7 +49,7 @@
 #include "STRstring.h"
 #include "STAarray.h"
 #include "boolean.h"
-
+#include "util.h"
 
 /** Return Values for *fromNet() functions **/
 #define SOFTERROR -1
