@@ -1,8 +1,8 @@
 /********************************************************************
- * $Author: lindner $
- * $Revision: 3.85 $
- * $Date: 1995/11/10 22:26:26 $
- * $Source: /home/arcwelder/GopherSrc/CVS/gopher+/object/GSgopherobj.c,v $
+ * $Author: jgoerzen $
+ * $Revision: 1.8 $
+ * $Date: 2002/03/19 20:07:16 $
+ * $Source: /var/cvs/gopher/object/GSgopherobj.c,v $
  * $State: Exp $
  *
  * Paul Lindner, University of Minnesota CIS.
@@ -15,6 +15,59 @@
  *********************************************************************
  * Revision History:
  * $Log: GSgopherobj.c,v $
+ * Revision 1.8  2002/03/19 20:07:16  jgoerzen
+ * GSgopherobj.c: Moved Regex.h include up.
+ *
+ * Regex.c, Regex.h: continuing full rewrites.
+ *
+ * Revision 1.7  2002/01/08 17:36:14  jgoerzen
+ * Finally builds!
+ *
+ * Changes:
+ *
+ *   * config.h.in: rebuilt by autoheader
+ *
+ *   * configure: rebuilt by autoconf
+ *
+ *   * configure.in:
+ *     * Added REGEXLIBS test for NetBSD -- look for re_comp in -lcompat
+ *     * Added checkes for term.h, re_comp.h, regex.h
+ *
+ *   * gopher/ourutils.c, gopher/CURcurses.c: Use term.h check
+ *
+ *   * gopher/Makefile.in, gopherd/Makefile.in, gophfilt/Makefile.in:
+ *     * Use REGEXLIBS
+ *
+ *   * gopher/globals.h, gopher/gopher.c: Remove sys_errlist
+ *
+ *   * object/GSgopherobj.c: Removed <regex.h> #include, now use
+ *     "Regex.h" that has proper regex determining logic
+ *
+ *   * object/Regex.h: Moved regex.h include to here.  Make it conditional
+ *     based on configure test.  Add conditional re_comp.h include.
+ *
+ * Revision 1.6  2001/01/17 21:48:05  jgoerzen
+ * Many fixes and tune-ups.  Now compiles cleanly with -Wall -Werror!
+ *
+ * Revision 1.5  2001/01/17 21:16:35  jgoerzen
+ * More psinrtf -> snprintf changes
+ *
+ * Revision 1.4  2000/12/26 22:48:12  s2mdalle
+ *
+ * Changed GSsendHeader(int, int) => GSsendHeader(int, long) because the
+ * second argument is often the file size, and an int may not be
+ * sufficient depending on platform.  Most calls use canned values of -1
+ * and -2 anyway.
+ *
+ * Revision 1.3  2000/12/20 01:19:20  jgoerzen
+ * Added patches from David Allen <s2mdalle@titan.vcu.edu>
+ *
+ * Revision 1.2  2000/08/23 00:18:41  jgoerzen
+ * Various bugfixes
+ *
+ * Revision 1.1.1.1  2000/08/19 00:28:56  jgoerzen
+ * Import from UMN Gopher 2.3.1 after GPLization
+ *
  * Revision 3.85  1995/11/10  22:26:26  lindner
  * Fix for wierd relative gopher URLs
  *
@@ -304,6 +357,7 @@
 
 #include "String.h"
 #include "STRstring.h"
+#include "Regex.h"
 #include <stdio.h>
 #include "compatible.h"
 #include <errno.h>
@@ -607,7 +661,7 @@ GStoNetURL(GopherObj *gs, char *url,  char *ticket)
 
 	  if (ftppath != NULL)
 	  {
-	       sprintf(url, "ftp://%.*s/", ftppath-ftphost, ftphost);
+	       sprintf(url, "ftp://%.*s/", (int) (ftppath - ftphost), ftphost);
 	       
 	       ftppath++;
 
@@ -809,9 +863,9 @@ GSaddView(GopherObj *gs, char *view, char *language, int estsize)
      VIewobj *temp;
 
      if (estsize > 960)
-	  sprintf(tmpstr, "%dk", (estsize + 512)/1024);
+	  snprintf(tmpstr, sizeof(tmpstr), "%dk", (estsize + 512)/1024);
      else
-      	  sprintf(tmpstr, ".%dk", ((estsize+64)*10)/1024);
+      	  snprintf(tmpstr, sizeof(tmpstr), ".%dk", ((estsize+64)*10)/1024);
 
      temp = VInew();
 
@@ -876,12 +930,14 @@ GStoNet(GopherObj *gs, int sockfd, GSformat fmt, char *ticket)
 	       if (strcasecmp(BLgetName(bl), "ONLYHTML")==0)
 		    return;
 	  }
-	  sprintf(buf + 1, "%s\t%s%s\t%s\t%d",
-		  GSgetTitle(gs) ? GSgetTitle(gs) : nullword,
-		  ticket         ? ticket : nullword,
-		  GSgetPath(gs)  ? GSgetPath(gs) : nullword,
-		  GSgetHost(gs)  ? GSgetHost(gs) : nullword,
-		  GSgetPort(gs));
+	  snprintf(buf + 1, 
+		   sizeof(buf) - 1,
+		   "%s\t%s%s\t%s\t%d",
+		   GSgetTitle(gs) ? GSgetTitle(gs) : nullword,
+		   ticket         ? ticket : nullword,
+		   GSgetPath(gs)  ? GSgetPath(gs) : nullword,
+		   GSgetHost(gs)  ? GSgetHost(gs) : nullword,
+		   GSgetPort(gs));
 	  
 	  if (GSisAsk(gs))
 	       strcat(buf, "\t?\r\n");
@@ -916,7 +972,8 @@ GStoNet(GopherObj *gs, int sockfd, GSformat fmt, char *ticket)
 	  GStoNetURL(gs, url, ticket);
 	  if (url[0] == '\0')
 	       return;
-	  sprintf(buf, "<A HREF=\"%s\">%s</A>\r\n", url, GSgetTitle(gs));
+	  snprintf(buf, sizeof(buf),
+		   "<A HREF=\"%s\">%s</A>\r\n", url, GSgetTitle(gs));
 	  writestring(sockfd, buf);
 
 	  if (GSgplusInited(gs)) {
@@ -931,7 +988,8 @@ GStoNet(GopherObj *gs, int sockfd, GSformat fmt, char *ticket)
 	  }
 
 	  if (GSgetWeight(gs) != 0) {
-	       sprintf(buf, "<DD>Score: %d\r\n", GSgetWeight(gs));
+	       snprintf(buf, sizeof(buf),
+			"<DD>Score: %d\r\n", GSgetWeight(gs));
 	       writestring(sockfd, buf);
 	  }
      }
@@ -998,7 +1056,7 @@ GSplustoNet(GopherObj *gs, int sockfd, char **filter, char *ticket)
 	       writestring(sockfd, GSgetModDate(gs));
 	       if (GSgetTTL(gs) > -1) {
 		    writestring(sockfd, "\r\n TTL: ");
-		    sprintf(tmpstr, "%d", GSgetTTL(gs));
+		    snprintf(tmpstr, sizeof(tmpstr), "%d", GSgetTTL(gs));
 		    writestring(sockfd, tmpstr);
 	       }
 	       writestring(sockfd, "\r\n");
@@ -1174,6 +1232,7 @@ GSplusfromNet(GopherObj *gs, int fd)
 extern int readfield();
 extern int readline();
 
+#if 0
 static void
 GSprocessObject(GopherObj *gs)
 {
@@ -1186,7 +1245,7 @@ GSprocessObject(GopherObj *gs)
      }
 #endif
 }
-
+#endif /* 0 */
 
 
 
@@ -1387,9 +1446,9 @@ GSmerge(GopherObj *gs, GopherObj *overlay)
 	      && GSgetType(gs) != A_FILE) {
 	       char *vs, vsize[64], *vc, vcomments[256];
 	       VIewobj *temp;
-	       if (vs = VIgetSize(GSgetView(gs, 0)))
+	       if ((vs = VIgetSize(GSgetView(gs, 0))))
 		    strcpy(vsize, vs);
-	       if (vc = VIgetComments(GSgetView(gs, 0)))
+	       if ((vc = VIgetComments(GSgetView(gs, 0))))
 		    strcpy(vcomments, vc);
 	       VIAdestroy(gs->gplus->Views);
 	       gs->gplus->Views    = VIAnew(10);
@@ -1411,6 +1470,7 @@ GSmerge(GopherObj *gs, GopherObj *overlay)
 
 /** Compare two GopherObjs ***/
 
+#if 0 /* unused */
 static int
 GScmp(GopherObj *gs1, GopherObj *gs2)
 {
@@ -1421,7 +1481,7 @@ GScmp(GopherObj *gs1, GopherObj *gs2)
 
      return(strcmp(GSgetTitle(gs1), GSgetTitle(gs2)));
 }
-
+#endif /* 0 */
 
 /*********** The following functions implement the gopher/gopher+
   protocol, mostly
@@ -1516,11 +1576,11 @@ GStransmit(GopherObj *gs, int sockfd, char *search, char *command, char *view)
  *
  */
 void
-GSsendHeader(int sockfd, int size)
+GSsendHeader(int sockfd, long size)
 {
      char sizestr[64];
 
-     sprintf(sizestr, "+%d\r\n", size);
+     snprintf(sizestr, sizeof(sizestr), "+%ld\r\n", size);
      writestring(sockfd, sizestr);
 }
 
@@ -1531,7 +1591,7 @@ GSsendErrorHeader(GopherObj *gs, int sockfd, int errortype, char *errormsg)
 {
      char tmpstr[512];
 
-     sprintf(tmpstr, "-%d %s\r\n", errortype, errormsg);
+     snprintf(tmpstr, sizeof(tmpstr), "-%d %s\r\n", errortype, errormsg);
      writestring(sockfd, tmpstr);
 }
 
@@ -1603,7 +1663,7 @@ GSgetginfo(GopherObj *gs, boolean   savename)
      int    sockfd, bytes;
      char   inputline[256];
      String *tempname = NULL;
-     char   temptype;
+     char   temptype='\0';
 
      if (!GSisGplus(gs))
 	  return;
@@ -1810,7 +1870,7 @@ GSfromLink(
 	       }
 
 	       /** Check for domain using regexps **/
-	       if (re_comp(host) != NULL)
+	       if (re_comp(host))
 		    break;
 	       if (re_exec(peer) == 1)
 		    BadDomain = TestResult;
@@ -1876,7 +1936,7 @@ GSfromURL(GopherObj *gs, char *urltxt, char *host, int port, int doneflags)
 	  }
 
 	  if (! (doneflags & G_PATH)) {
-	       sprintf(tempbuf, "GET /%s", URLgetPath(url));
+	       snprintf(tempbuf, sizeof(tempbuf), "GET /%s", URLgetPath(url));
 	       GSsetPath(gs, tempbuf);
 	  } 
 	  doneflags |= G_PATH;
@@ -1936,15 +1996,24 @@ GSfromURL(GopherObj *gs, char *urltxt, char *host, int port, int doneflags)
 	       GSsetPath(gs, "");
 	  doneflags |= G_PATH;
 	  break;
+/* Unhandled cases... */
+     case gopher:
+     case http:
+     case ftp:
+     case news:
+     case unset:
+     case unknown:
      }
 
      if (serviceType == ftp) {
 	  if (!(doneflags & G_PATH)) {
 	       if (URLgetPath(url) != NULL && *URLgetPath(url) != '\0')
-		    sprintf(tempbuf, "ftp:%s@/%s", URLgetHost(url),
-			    URLgetPath(url));
+		    snprintf(tempbuf, sizeof(tempbuf), 
+			     "ftp:%s@/%s", URLgetHost(url),
+			     URLgetPath(url));
 	       else
-		    sprintf(tempbuf, "ftp:%s@/", URLgetHost(url));
+		    snprintf(tempbuf, sizeof(tempbuf), 
+			     "ftp:%s@/", URLgetHost(url));
 
 	       GSsetPath(gs, tempbuf);
 	       doneflags |= G_PATH;
@@ -2003,7 +2072,7 @@ GStoLink(GopherObj *gs, int fd, BOOLEAN AddInfo)
      writestring(fd, "\nHost=");
      writestring(fd, GSgetHost(gs));
      writestring(fd, "\nPort=");
-     sprintf(portnum, "%d", GSgetPort(gs));
+     snprintf(portnum, sizeof(portnum), "%d", GSgetPort(gs));
      writestring(fd, portnum);
      writestring(fd, "\n");
      if (GSisGplus(gs) && GSgplusInited(gs) && AddInfo) {
