@@ -1,7 +1,7 @@
 /********************************************************************
  * $Author: jgoerzen $
- * $Revision: 1.1.1.1 $
- * $Date: 2000/08/19 00:28:56 $
+ * $Revision: 1.5 $
+ * $Date: 2002/03/19 20:07:16 $
  * $Source: /var/cvs/gopher/object/Regex.c,v $
  * $Status: $
  *
@@ -15,6 +15,21 @@
  *********************************************************************
  * Revision History:
  * $Log: Regex.c,v $
+ * Revision 1.5  2002/03/19 20:07:16  jgoerzen
+ * GSgopherobj.c: Moved Regex.h include up.
+ *
+ * Regex.c, Regex.h: continuing full rewrites.
+ *
+ * Revision 1.4  2002/03/19 19:53:31  jgoerzen
+ * *** empty log message ***
+ *
+ * Revision 1.3  2002/02/12 20:50:21  jgoerzen
+ * Beginning of MacOS X (Darwin) support.
+ * Many modifications to Regex.[ch], see debian/changelog for details.
+ *
+ * Revision 1.2  2002/02/12 19:54:18  jgoerzen
+ * Updated with regex fixes
+ *
  * Revision 1.1.1.1  2000/08/19 00:28:56  jgoerzen
  * Import from UMN Gopher 2.3.1 after GPLization
  *
@@ -27,17 +42,44 @@
  *
  *********************************************************************/
 
+#define __GOPHER_REGEX_C__
+
 /*
  * If you're using gcc on Solaris you might need to copy /usr/include/regexp.h
  * to /opt/whatever/regexp.h
  */
 
 #define  REGEX_CODEIT    /* only include sysv regex code once.. */
+#include "config.h"
 #include "Regex.h"
+#include "Malloc.h"
+
+/**************************************************
+ POSIX
+**************************************************/
 
 #ifdef REGEX_POSIX
-char *REGEX_param = NULL;
-#endif
+regex_t preg;
+int pregallocated = 0;
+
+char *posix_re_comp(char *regex) {
+  if (pregallocated) {
+    regfree(&preg);
+  }
+
+  pregallocated = 1;
+  return regcomp(&preg, regex, REG_NOSUB) ? "regcomp error" : NULL;
+}
+
+int posix_re_exec(char *string) {
+  return ! regexec(&preg, string, 0, NULL, 0);
+}
+  
+#endif /* REGEX_POSIX */
+
+/**************************************************
+ SYSV
+**************************************************/
 
 #ifdef REGEX_SYSV
 
@@ -45,8 +87,7 @@ char *REGEX_param = NULL;
 static char expbuf[ESIZE];
 
 char *
-re_comp(expr)
-  char *expr;
+re_comp(char *expr)
 {
      char *result;
 
@@ -56,10 +97,9 @@ re_comp(expr)
 }
 
 int
-re_exec(string)
-  char *string;
+re_exec(char *string)
 {
      return(step(string, expbuf));
 }
 
-#endif
+#endif /* REGEX_SYSV */
