@@ -1,8 +1,8 @@
 /********************************************************************
- * $Author: lindner $
- * $Revision: 3.22 $
- * $Date: 1995/09/25 22:07:20 $
- * $Source: /home/arcwelder/GopherSrc/CVS/gopher+/object/Sockets.c,v $
+ * $Author: jgoerzen $
+ * $Revision: 1.2 $
+ * $Date: 2002/03/19 20:42:48 $
+ * $Source: /var/cvs/gopher/object/Sockets.c,v $
  * $State: Exp $
  *
  * Paul Lindner, University of Minnesota CIS.
@@ -15,6 +15,14 @@
  *********************************************************************
  * Revision History:
  * $Log: Sockets.c,v $
+ * Revision 1.2  2002/03/19 20:42:48  jgoerzen
+ *   * Removed the DOMAIN configure support, DOMAIN_NAME in gopherd,
+ *     backupdomain in Socket.c, etc.  This should prevent the no.domain.name
+ *     problem that people have been seeing.  Regenerated configure stuff.
+ *
+ * Revision 1.1.1.1  2000/08/19 00:28:56  jgoerzen
+ * Import from UMN Gopher 2.3.1 after GPLization
+ *
  * Revision 3.22  1995/09/25  22:07:20  lindner
  * Ansification
  *
@@ -167,7 +175,7 @@ SOCKbind_to_port(int port)
  */
 
 char *
-SOCKgetDNSname(char *backupdomain, char *gdchost)
+SOCKgetDNSname(char *gdchost)
 {
      static char DNSname[MAXHOSTNAMELEN];
      struct hostent *hp;
@@ -192,8 +200,6 @@ SOCKgetDNSname(char *backupdomain, char *gdchost)
       */
      if ( hp!=NULL && strlen(hp->h_name) > strlen(DNSname) ) 
 	  strncpy( DNSname, hp->h_name, MAXHOSTNAMELEN );
-     else
-	  strcat(DNSname, backupdomain);
 
      return(DNSname);
 }
