@@ -1,8 +1,8 @@
 /********************************************************************
- * $Author: lindner $
- * $Revision: 3.7 $
- * $Date: 1995/09/25 22:07:21 $
- * $Source: /home/arcwelder/GopherSrc/CVS/gopher+/object/Sockets.h,v $
+ * $Author: jgoerzen $
+ * $Revision: 1.2 $
+ * $Date: 2002/03/19 20:42:48 $
+ * $Source: /var/cvs/gopher/object/Sockets.h,v $
  * $State: Exp $
  *
  * Paul Lindner, University of Minnesota CIS.
@@ -15,6 +15,14 @@
  *********************************************************************
  * Revision History:
  * $Log: Sockets.h,v $
+ * Revision 1.2  2002/03/19 20:42:48  jgoerzen
+ *   * Removed the DOMAIN configure support, DOMAIN_NAME in gopherd,
+ *     backupdomain in Socket.c, etc.  This should prevent the no.domain.name
+ *     problem that people have been seeing.  Regenerated configure stuff.
+ *
+ * Revision 1.1.1.1  2000/08/19 00:28:56  jgoerzen
+ * Import from UMN Gopher 2.3.1 after GPLization
+ *
  * Revision 3.7  1995/09/25  22:07:21  lindner
  * Ansification
  *
@@ -86,7 +94,7 @@ int  SOCKconnect(char *hostname, int port);
 int  SOCKlisten(struct sockaddr_in * We);
 int  SOCKaccept(int s, struct sockaddr_in we);
 void SOCKnetnames(int  sockfd, char *host_name, char *ipnum);
-char *SOCKgetDNSname(char *backupdomain, char *gdchost);
+char *SOCKgetDNSname(char *gdchost);
 int  SOCKgetPort(int fd);
 
 #define ErrSocketGetService 	-1
