@@ -1,8 +1,8 @@
 /********************************************************************
- * $Author: lindner $
- * $Revision: 3.19 $
- * $Date: 1995/10/31 16:53:57 $
- * $Source: /home/arcwelder/GopherSrc/CVS/gopher+/object/url.c,v $
+ * $Author: jgoerzen $
+ * $Revision: 1.4 $
+ * $Date: 2002/03/19 16:57:41 $
+ * $Source: /var/cvs/gopher/object/url.c,v $
  * $State: Exp $
  *
  * Paul Lindner, University of Minnesota CIS.
@@ -15,6 +15,18 @@
  *********************************************************************
  * Revision History:
  * $Log: url.c,v $
+ * Revision 1.4  2002/03/19 16:57:41  jgoerzen
+ * Fixed type handling.
+ *
+ * Revision 1.3  2001/01/17 21:16:35  jgoerzen
+ * More psinrtf -> snprintf changes
+ *
+ * Revision 1.2  2000/12/20 01:19:20  jgoerzen
+ * Added patches from David Allen <s2mdalle@titan.vcu.edu>
+ *
+ * Revision 1.1.1.1  2000/08/19 00:28:56  jgoerzen
+ * Import from UMN Gopher 2.3.1 after GPLization
+ *
  * Revision 3.19  1995/10/31  16:53:57  lindner
  * Small fix for ftp urls..
  *
@@ -135,7 +147,9 @@ URLfromGS(Url *url, GopherObj *gs, char *ticket)
 	       *(cp++) = '@';
 	       Tohexstr(path, cp);
 	  }
-	  sprintf(u + strlen(u), ":%d", GSgetPort(gs));
+	  snprintf(u + strlen(u), 
+		   sizeof(u) - strlen(u) - 1,
+		   ":%d", GSgetPort(gs));
      }
      else if (path != NULL)
      {
@@ -143,7 +157,9 @@ URLfromGS(Url *url, GopherObj *gs, char *ticket)
 	       /* http://[host]:[port][path without "GET "] */
 	       strcpy(u, "http://");
 	       Tohexstr(GSgetHost(gs), u+7);
-	       sprintf(u + strlen(u), ":%d", GSgetPort(gs));
+	       snprintf(u + strlen(u), 
+			sizeof(u) - strlen(u) - 1,
+			":%d", GSgetPort(gs));
 	       Tohexstr(path + 4, u + strlen(u));
 	  } else if (strncmp(path, "ftp:", 4) == 0) {
 	       /** ftp://[host]/[pathname]; **/
@@ -161,7 +177,9 @@ URLfromGS(Url *url, GopherObj *gs, char *ticket)
 	       /* gopher://[host]:[port]/[type][path] */
 	       strcpy(u, "gopher://");
 	       Tohexstr(GSgetHost(gs), u + 9);
-	       sprintf(u + strlen(u), ":%d/%c", GSgetPort(gs), GSgetType(gs));
+	       snprintf(u + strlen(u),
+			sizeof(u) - strlen(u) - 1,
+			":%d/%c", GSgetPort(gs), GSgetType(gs));
 	       if (ticket != NULL && strlen(ticket) > 0)
 		    Tohexstr(ticket, u+strlen(u));
 	       Tohexstr(path, u + strlen(u));
@@ -275,17 +293,17 @@ URLparse(Url *url)
      } else {
 	  Fromhexstr(cp3, cp3);
 	  URLsetPath(url,cp3);
-	  *cp3 = '\0';
+	  *(cp3++) = '\0';      /* trunc the host part, remove sep slash, now
+                                   cp3 points at the type. */
      }
 
      if (serviceType == gopher) {
 	  if (cp3 != NULL && (int)strlen(cp3) > 1) {
 	       URLsetGophType(url, *(cp3++));
 	       URLsetPath(url,cp3++);
-	  }
-	  else
+	  } else {
 	       URLsetGophType(url, '1');
-	  
+          }
      }
 
 
@@ -340,7 +358,10 @@ URLparse(Url *url)
 	       break;
 	  case news:
 	       URLsetPort(url, 119);
-	       break;
+               break;
+          case ftp:
+          case unset:
+          case unknown:
 	  }
 	  URLsetHost(url, cp);
      }
